@@ -4,6 +4,7 @@ The system service is used to install, delete and retrieve information about
 """
 import datetime
 import json
+import traceback
 import logging
 import time
 import typing
@@ -11,57 +12,56 @@ import uuid
 from dataclasses import dataclass
 from typing import Iterator
 
-from transiter import models, exceptions, __metadata__
-from transiter.data import dbconnection
-from transiter.data.dams import feeddam, systemdam, genericqueries
+from transiter import exceptions, __metadata__
+from transiter.db import dbconnection, models
+from transiter.db.queries import feedqueries, genericqueries, systemqueries
 from transiter.executor import celeryapp
 from transiter.scheduler import client
-from transiter.services import systemconfigreader, views
-from transiter.services.update import updatemanager
+from transiter.services import systemconfigreader, views, updatemanager
 
 logger = logging.getLogger(__name__)
 
 
 @dbconnection.unit_of_work
 def list_all() -> typing.List[views.System]:
-    """
-    List all installed systems.
-    """
-    return list(map(views.System.from_model, systemdam.list_all()))
+    return list(map(views.System.from_model, systemqueries.list_all()))
 
 
 @dbconnection.unit_of_work
 def get_by_id(system_id) -> views.SystemLarge:
-    """
-    Get information on a specific system.
-    """
-    system = systemdam.get_by_id(system_id)
+    system = systemqueries.get_by_id(system_id)
     if system is None:
         raise exceptions.IdNotFoundError(models.System, system_id=system_id)
     response = views.SystemLarge.from_model(system)
     if system.status != system.SystemStatus.ACTIVE:
         return response
-    response.stops = views.StopsInSystem.from_model(
-        system, systemdam.count_stops_in_system(system_id)
-    )
-    response.routes = views.RoutesInSystem.from_model(
-        system, systemdam.count_routes_in_system(system_id)
-    )
-    response.feeds = views.FeedsInSystem.from_model(
-        system, systemdam.count_feeds_in_system(system_id)
-    )
-    response.agency_alerts = list(
-        map(
-            views.AlertLarge.from_model,
-            systemdam.list_all_alerts_associated_to_system(system.pk),
+    for attr, view, relationship in (
+        ("agencies", views.AgenciesInSystem, models.System.agencies),
+        ("stops", views.StopsInSystem, models.System.stops),
+        ("routes", views.RoutesInSystem, models.System.routes),
+        ("feeds", views.FeedsInSystem, models.System.feeds),
+        ("transfers", views.TransfersInSystem, models.System.transfers),
+    ):
+        setattr(
+            response,
+            attr,
+            view.from_model(
+                system,
+                genericqueries.count_number_of_related_entities(relationship, system),
+            ),
         )
-    )
     return response
 
 
+@dbconnection.unit_of_work
+def is_active(system_id):
+    system = systemqueries.get_by_id(system_id)
+    return system is not None and system.status != models.System.SystemStatus.ACTIVE
+
+
 def set_auto_update_enabled(system_id, auto_update):
     with dbconnection.inline_unit_of_work():
-        response = systemdam.set_auto_update_enabled(system_id, auto_update)
+        response = systemqueries.set_auto_update_enabled(system_id, auto_update)
     client.refresh_tasks()
     return response
 
@@ -97,7 +97,7 @@ def install(system_id, config_str, extra_settings, config_source_url, sync=True)
 
 @dbconnection.unit_of_work
 def get_update_by_id(system_update_id) -> views.SystemUpdate:
-    system_update = systemdam.get_update_by_pk(system_update_id)
+    system_update = systemqueries.get_update_by_pk(system_update_id)
     if system_update is None:
         raise exceptions.IdNotFoundError(models.SystemUpdate, id=str(system_update_id))
     result = views.SystemUpdate.from_model(system_update)
@@ -107,7 +107,7 @@ def get_update_by_id(system_update_id) -> views.SystemUpdate:
 
 @dbconnection.unit_of_work
 def _create_system_update(system_id, config_str, extra_settings, config_source_url):
-    system = systemdam.get_by_id(system_id)
+    system = systemqueries.get_by_id(system_id)
     if system is not None:
         invalid_statuses_for_update = {
             models.System.SystemStatus.SCHEDULED,
@@ -124,9 +124,11 @@ def _create_system_update(system_id, config_str, extra_settings, config_source_u
             system.status = models.System.SystemStatus.SCHEDULED
     else:
         system = models.System(
-            id=system_id, status=models.System.SystemStatus.SCHEDULED,
+            id=system_id,
+            name="(Awaiting install for full name)",
+            status=models.System.SystemStatus.SCHEDULED,
         )
-        systemdam.create(system)
+        systemqueries.create(system)
 
     update = models.SystemUpdate(
         system=system,
@@ -157,32 +159,34 @@ def _execute_system_update(system_update_pk):
             system_update_pk
         )
         for feed_id in feed_ids_to_update:
-            update_status, __ = updatemanager.execute_feed_update(
+            feed_update, exception = updatemanager.execute_feed_update(
                 feed_update_pk=updatemanager.create_feed_update(
                     context.system_id, feed_id
                 )
             )
-            if update_status != models.FeedUpdate.Status.SUCCESS:
-                raise exceptions.InstallError(
-                    message="Failed to update feed with id={}; reason: {}".format(
-                        feed_id, update_status
+            if feed_update.status != models.FeedUpdate.Status.SUCCESS:
+                if exception is None:
+                    exception = exceptions.InstallError(
+                        message=(
+                            f"Failed to update feed (id={feed_id}); "
+                            f"status: {feed_update.status}; "
+                            f"result: {feed_update.result}"
+                        )
                     )
-                )
+                raise exceptions.InstallError(
+                    message=(
+                        f"Failed to update a feed (id={feed_id}) "
+                        f"that is required for install"
+                    )
+                ) from exception
         for feed_id in feed_ids_to_delete:
             _delete_feed(context.system_id, feed_id)
         _mark_update_completed(
             context, models.SystemUpdate.Status.SUCCESS,
         )
-    except exceptions.TransiterException as e:
+    except Exception:
         _mark_update_completed(
-            context, models.SystemUpdate.Status.FAILED, json.dumps(e.response()),
-        )
-        logger.debug("Install or update of system failed", exc_info=True)
-    except Exception as e:
-        _mark_update_completed(
-            context,
-            models.SystemUpdate.Status.FAILED,
-            json.dumps(exceptions.UnexpectedError(str(e)).response()),
+            context, models.SystemUpdate.Status.FAILED, traceback.format_exc()
         )
         logger.debug("Install or update of system failed", exc_info=True)
 
@@ -199,7 +203,7 @@ class _SystemUpdateContext:
 
 @dbconnection.unit_of_work
 def _mark_update_started(system_update_pk) -> _SystemUpdateContext:
-    system_update = systemdam.get_update_by_pk(system_update_pk)
+    system_update = systemqueries.get_update_by_pk(system_update_pk)
     system_update.status = models.SystemUpdate.Status.IN_PROGRESS
     system = system_update.system
     prior_auto_update_setting = system.auto_update_enabled
@@ -221,7 +225,7 @@ def _mark_update_completed(
     """
     Set the status of a transit system, if that system exists in the DB.
     """
-    system_update = systemdam.get_update_by_pk(context.update_pk)
+    system_update = systemqueries.get_update_by_pk(context.update_pk)
     system_update.status = final_status
     system_update.status_message = final_status_message
     system_update.total_duration = time.time() - context.start_time
@@ -236,13 +240,14 @@ def _mark_update_completed(
 
 @dbconnection.unit_of_work
 def _install_system_configuration(system_update_pk):
-    system_update = systemdam.get_update_by_pk(system_update_pk)
+    system_update = systemqueries.get_update_by_pk(system_update_pk)
     extra_settings = json.loads(system_update.config_parameters)
     system_update.config = systemconfigreader.render_template(
         system_update.config_template, extra_settings
     )
     system_config = systemconfigreader.read(system_update.config, extra_settings)
     system = system_update.system
+    system.name = system_config[systemconfigreader.NAME]
 
     # Service maps must come first in case calculations are triggered
     # by install_required feed updates
@@ -257,7 +262,7 @@ def delete_by_id(system_id, error_if_not_exists=True, sync=True):
     Delete a transit system
     """
     with dbconnection.inline_unit_of_work():
-        system = systemdam.get_by_id(system_id)
+        system = systemqueries.get_by_id(system_id)
         if system is not None:
             system.status = models.System.SystemStatus.DELETING
             if not sync:
@@ -284,7 +289,7 @@ def _complete_delete_operation_async(system_id):
 def _complete_delete_operation(system_id):
     feed_ids = set()
     with dbconnection.inline_unit_of_work():
-        system = systemdam.get_by_id(system_id)
+        system = systemqueries.get_by_id(system_id)
         for feed in system.feeds:
             feed_ids.add(feed.id)
 
@@ -292,7 +297,7 @@ def _complete_delete_operation(system_id):
         _delete_feed(system_id, feed_id)
 
     with dbconnection.inline_unit_of_work():
-        systemdam.delete_by_id(system_id)
+        systemqueries.delete_by_id(system_id)
 
 
 def _delete_feed(system_id, feed_id):
@@ -301,7 +306,7 @@ def _delete_feed(system_id, feed_id):
         updatemanager.create_feed_flush(system_id, feed_id)
     )
     with dbconnection.inline_unit_of_work():
-        feeddam.delete_in_system_by_id(system_id, feed_id)
+        feedqueries.delete_in_system_by_id(system_id, feed_id)
 
 
 def _save_feed_configuration(system, feeds_config):
@@ -346,9 +351,18 @@ def _build_feeds_from_config(feeds_config) -> Iterator[models.Feed]:
         feed.custom_parser = config[systemconfigreader.PARSER].get(
             systemconfigreader.CUSTOM
         )
+        parser_options = config[systemconfigreader.PARSER].get(
+            systemconfigreader.OPTIONS
+        )
+        feed.parser_options = (
+            json.dumps(parser_options, indent=2) if parser_options is not None else None
+        )
         feed.url = config[systemconfigreader.HTTP][systemconfigreader.URL]
         feed.headers = json.dumps(
-            dict(config[systemconfigreader.HTTP][systemconfigreader.HEADERS])
+            dict(config[systemconfigreader.HTTP][systemconfigreader.HEADERS]), indent=2
+        )
+        feed.http_timeout = config[systemconfigreader.HTTP].get(
+            systemconfigreader.TIMEOUT
         )
         feed.auto_update_enabled = config[systemconfigreader.AUTO_UPDATE][
             systemconfigreader.ENABLED
